from django.db import models
from django.forms import ModelForm

# Create your models here.

class Application(models.Model):
    descriptor = models.CharField(max_length=200)
    label = models.CharField(max_length=100)

    def __unicode__(self):
        return self.label

class Category(models.Model):
    application = models.ForeignKey(Application)
    label = models.CharField(max_length=50)

    def __unicode__(self):
        return self.label

class Icon(models.Model):
    application = models.ForeignKey(Application)
    filename = models.CharField(max_length=100)

    def __unicode__(self):
        return self.filename

class Accomplishment(models.Model):
    application = models.ForeignKey(Application)
    descriptor = models.CharField(max_length=100)
    title = models.CharField(max_length=50)
    description = models.CharField(max_length=100)
    needsinformation = models.TextField()
    categories = models.ManyToManyField(Category, blank=True, null=True)
    icon = models.ManyToManyField(Icon)
    needssigning = models.BooleanField()
    depends = models.ForeignKey('self', blank=True, null=True)
    summary = models.TextField()
    steps = models.TextField()
    links = models.TextField(blank=True, null=True)
    helpres = models.TextField(blank=True, null=True)

    def __unicode__(self):
        return self.title

class AccomplishmentDiff(models.Model):
    accomplishment = models.ForeignKey(Accomplishment)
    user = models.CharField(max_length=50)
    description = models.CharField(max_length=100)
    summary = models.TextField()
    steps = models.TextField()
    links = models.TextField(blank=True, null=True)
    helpres = models.TextField(blank=True, null=True)

    def __unicode__(self):
        return self.description

"""class Step(models.Model):
    accomplishment = models.ForeignKey(Accomplishment)
    number = models.IntegerField()
    label = models.CharField(max_length=200)

    def __unicode__(self):
        return self.label

class Link(models.Model):
    accomplishment = models.ForeignKey(Accomplishment)
    label = models.CharField(max_length=200)

    def __unicode__(self):
        return self.label

class Help(models.Model):
    accomplishment = models.ForeignKey(Accomplishment)
    label = models.CharField(max_length=200)

    def __unicode__(self):
        return self.label


class ExtraInformation(models.Model):
    application = models.ForeignKey(Application)
    label = models.CharField(max_length=50)

    def __unicode__(self):
        return self.label
"""

class AccomplishmentForm(ModelForm):
    class Meta:
        model = Accomplishment
        exclude = ('title', 'needssigning', 'application', 'descriptor', 'needsinformation')

"""class StepForm(ModelForm):
    class Meta:
        model = Step
"""
